@@ -128,10 +128,13 @@ cm_certsave_n_main(int fd, struct cm_store_ca *ca, struct cm_store_entry *entry,
 			      NSS_INIT_NOMODDB);
 	ec = PORT_GetError();
 	if (ctx == NULL) {
-		if ((ec == SEC_ERROR_BAD_DATABASE) && readwrite) {
+		if ((ec == SEC_ERROR_READ_ONLY) && readwrite) {
+		        ec = PR_NO_ACCESS_RIGHTS_ERROR;
+		} else if ((ec == SEC_ERROR_BAD_DATABASE) && readwrite) {
 			switch (errno) {
 			case EACCES:
 			case EPERM:
+			case ENOENT:
 				ec = PR_NO_ACCESS_RIGHTS_ERROR;
 				break;
 			default:
@@ -471,6 +474,20 @@ cm_certsave_n_main(int fd, struct cm_store_ca *ca, struct cm_store_entry *entry,
 						 PR_FALSE,
 						 entry->cm_cert_nickname);
 			ec = PORT_GetError();
+			if (error == SECSuccess) {
+				/* If NSS uses SQL DB storage, CERT_ImportCerts creates
+				 * an incomplete internal state (the cert isn't
+				 * associated with the private key, and calling
+				 * PK11_FindKeyByAnyCert returns no result).
+				 * As a workaround, we import the cert again using 
+				 * PK11_ImportCert, which magically fixes the issue.
+				 * See rhbz#1532188 */
+				error = PK11_ImportCert(PK11_GetInternalKeySlot(),
+					returned[0],
+					CK_INVALID_HANDLE,
+					returned[0]->nickname,
+					PR_FALSE);
+			}
 			if (error == SECSuccess) {
 				cm_log(1, "Imported certificate \"%s\", got "
 				       "nickname \"%s\".\n",
