@@ -296,7 +296,10 @@ main(int argc, const char **argv)
 	}
 
 	umask(S_IRWXG | S_IRWXO);
-	cm_log_set_method(cm_log_stderr);
+	if (isatty(STDERR_FILENO))
+		cm_log_set_method(cm_log_stderr);
+	else
+		cm_log_set_method(cm_log_syslog);
 	cm_log_set_level(verbose);
 
 	nctx = NSS_InitContext(CM_DEFAULT_CERT_STORAGE_LOCATION,
@@ -476,9 +479,17 @@ main(int argc, const char **argv)
 	/* Read the client password and/or PIN, if we need to. */
 	if ((pwdfile != NULL) && (pwd == NULL)) {
 		pwd = cm_submit_u_from_file(pwdfile);
+        if (pwd != NULL) {
+            pwd = talloc_strndup(ctx, pwd,
+                        strcspn(pwd, "\r\n"));
+		}
 	}
 	if ((pinfile != NULL) && (pin == NULL)) {
 		pin = cm_submit_u_from_file(pinfile);
+        if (pin != NULL) {
+            pin = talloc_strndup(ctx, pin,
+                        strcspn(pin, "\r\n"));
+		}
 	}
 
 	/* Figure out which form and arguments to use. */
